/*****************************************************
This program was produced by the
CodeWizardAVR V1.25.1 Standard
Automatic Program Generator
 Copyright 1998-2006 Pavel Haiduc, HP InfoTech s.r.l.
http://www.hpinfotech.com

Project : Temperature display
Version : V3
Date    : 7. 11. 2006
Author  : Jaroslav Strba                  
Company : ECCO Slovakia                   
Comments: 
Zobrazenie a regulcia teploty s SMT160-30


Chip type           : ATtiny2313
Clock frequency     : 4,000000 MHz
Memory model        : Tiny
External SRAM size  : 0
Data Stack size     : 32

Nastavenie Fuse Bits - ATtiny2313: (X - prestaven)
        SELFPRGEN - Self Programming Enable - 1 (unprogrammed)
        DWEN - debugWIRE Enable - 1 (unprogrammed)
        EESAVE - EEPROM memory is preserved through the Chip Erase - 0 (programmed, EEPROM preserved) X
        SPIEN - Enable Serial Program and Data Downloading - 0 (programmed, SPI prog. enabled)
        WDTON - Watchdog Timer always on - 0 (programmed) X
        BODLEVEL2 - Brown-out Detector trigger level - 1 (unprogrammed) - Nastavenie BODLEVEL 2,1,0 = 100 = 4,3V
        BODLEVEL1 - Brown-out Detector trigger level - 0 (programmed) X
        BODLEVEL0 - Brown-out Detector trigger level - 0 (programmed) X
        RSTDISBL - External Reset disable - 1 (unprogrammed)
        CKDIV8 - Divide clock by 8 - 0 (programmed)
        CKOUT - Output Clock on CKOUT pin - 1 (unprogrammed)
        SUT1 - Select start-up time - 0 (programmed)    X
        SUT0 - Select start-up time - 0 (programmed)
        CKSEL3 - Select Clock source - 0 (programmed) - Nastavenie CKSEL3,2,1,0 = 0010 = internal 4MHz
        CKSEL2 - Select Clock source - 0 (programmed) X
        CKSEL1 - Select Clock source - 1 (unprogrammed) X
        CKSEL0 - Select Clock source - 0 (programmed)

*****************************************************/

#include <tiny2313.h>
#include <bcd.h>
#include <1wire.h>
#include <delay.h>

//Defincia premennch a kontnt
#define O_SegD PORTA.0    //segment D LED displeja
#define O_SegE PORTA.1    //segment E LED displeja
#define I_Tl PINB.0    //vstup s tlatka
#define O_Heat PORTB.1    //vstup pre riadenie ohrevu
#define O_SegB PORTB.2    //segment B LED displeja
#define O_Dig3 PORTB.3    //3 digit LED displeja
#define O_SegF PORTB.4    //segment F LED displeja
#define O_Horn PORTB.5    //vstup pre sirnku / MOSI
#define I_InS PINB.6    //vstup zo senzoru teploty SMT160 / MISO
#define O_SupS PORTB.7    //napjanie senzoru teploty SMT160 / SCK
#define O_SegA PORTD.0    //segment A LED displeja
#define O_Dig1 PORTD.1    //1 digit LED displeja
#define O_SegH PORTD.2    //segment H LED displeja
#define O_Dig2 PORTD.3    //2 digit LED displeja
#define O_SegC PORTD.4    //segment C LED displeja
#define O_SegG PORTD.5    //segment G LED displeja
#define I_Bat PIND.6    //napjanie je z batrie
#define CheckBit(Adress,BIT) (Adress&(1<<BIT))          //pre kontrolu bitov
#define SetBit(Adress,BIT) (Adress|=(1<<BIT))           //pre nahodenie bitu
#define ClearBit(Adress,BIT) (Adress&=~(1<<BIT))         //pre zhodenie bitu
#define CharE 0xBF      //definovnie znaku "-" pre zobrazenie
#define Char_o 0xA3;    //definovanie znaku o - premintky

//Prkazy pre 1 wire DS18B20
#define DS18B20_CMD_CONVERTTEMP 0x44
#define DS18B20_CMD_RSCRATCHPAD 0xbe
#define DS18B20_CMD_WSCRATCHPAD 0x4e
#define DS18B20_CMD_CPYSCRATCHPAD 0x48
#define DS18B20_CMD_RECEEPROM 0xb8
#define DS18B20_CMD_RPWRSUPPLY 0xb4
#define DS18B20_CMD_SEARCHROM 0xf0
#define DS18B20_CMD_READROM 0x33
#define DS18B20_CMD_MATCHROM 0x55
#define DS18B20_CMD_SKIPROM 0xcc
#define DS18B20_CMD_ALARMSEA0RCH 0xec

//tabuka kdov pre zobrazenie sel 0 a 9 na sedemsegmentovom displeji - najni bit je segment A a najvy je H
flash unsigned char TableChar[10]={0xC0,0xF9,0xA4,0xB0,0x99,0x92,0x82,0xF8,0x80,0x90};
flash unsigned char TableTimer[4]={0xBF,0xFB,0xF7,0xEF};      //pre yobrayenie beiacich mintiek
bit F_Tl;               //vstup z tlatka je platn
bit F_LongTl;           //tl. bolo staen dlh as
bit F_ErrorS;           //flag - chyba senzoru teploty
bit F_NegTemp;          //flag - zporn teplota
bit F_Flash;            //flag - blikanie displeja
bit F_HalfS;            //flag - pol sekundy
bit F_Timer;            //flag - tart odtavania mintiek
bit F_FiveSek;          //flag - 5 seknd
bit F_NoFlash;          //flag - neblikanie displeja
bit F_Auto;             //flag - automatick reim aktvny
bit F_TempFinish;       //flag - ukonenie ohrevu pri automatike
bit F_Idle;              //flag - bude prechdza do Idle mdu (pri prvom tarte stlaen tl.)
bit F_IdleS;            //flag - tat Idle mdu
bit F_Alarm;
bit F_Signal;           //flag - pipnutie pre signalizaciu
bit F_Aux_M;            //flag - pomocn pam
unsigned char Conv_DS18B20=1;         // Kroky tania teploty
unsigned char CountFiveSek;  //ta pre 5 seknd - nvrat s nastavovacch mdov
unsigned char PointDig; //ukazovate zobrazovanho digitu
unsigned char Digits[3];     //register hodnoty pre 3 digity
unsigned char Teplota;  //register pre ukladanie skutonej teploty - bin
//unsigned int T1;        //doba H od SMT160
//unsigned int T2;       //doba jednho cyklu SMT160
unsigned char SetTemp;        //nastaven teplota - RAM
unsigned char SetTimer;         //nastaven as mintiek
unsigned char Timer;            //hodnota mintiek
unsigned char ChangeNum;                   //pre zobrazenie unpravovanej hodnoty
unsigned char RunTimer;         //pomocn register pre zobrazenie behu mintiek
unsigned char CountTimMin;      //register pre 1 mintu
unsigned char CountTl;       //ta pre sledovanie dlhch asov - stlaen tl.        
unsigned char ModeRAM;          
unsigned char CountIdle;        //ta pre prechod do Idle mdu
unsigned char temperature_l;
unsigned char temperature_h;

eeprom char SetTempEE;  //nastaven teplota - EEPROM
eeprom char SetTimerEE; //nastaven hodnota mintiek EEPROM

//Elimincia nepodstatnch nl
void ElZero(void)
{
	if (Digits[0]==TableChar[0])    //nezobrazenie nepodstatnch nl
		{
			Digits[0]=0xFF;
			if (Digits[1]==TableChar[0]) Digits[1]=0xFF;
		}
}

//Prprava dt pre zobrazenie na displej
void TemperatureDisplay (void)
{
	unsigned char Temp;     //doasn premmen
	if (Teplota>=200) Temp=Teplota-200, Digits[0]=TableChar[2];     //zistenie i je teplota vyia ako 100C, prprava dt na 1 displeji
	else if (Teplota>=100) Temp=Teplota-100, Digits[0]=TableChar[1];
	else Digits[0]=TableChar[0], Temp=Teplota;
	Temp=bin2bcd(Temp);  //prevod binrnej informcie teploty na BCD
	Digits[1]=TableChar[Temp>>4];   //prprava desiatok teploty
	Digits[2]=TableChar[Temp&0x0F]; //prprava jednotiek teploty
	ElZero();       //Elimincia nepodstatnch nl
	if (F_NegTemp)                               //zobrazenie znaku "-" ke je mnusov teplota
			{
			if (Digits[1]==0xFF) Digits[1]=CharE;
			else Digits[0]=CharE;
			}
}

//Zobrazenie nastavenej teploty - 0 a 99C
void SetTemperatureDisplay(void)
{
	unsigned char Temp;     //doasn premmen
	Temp=bin2bcd(ChangeNum);  //prevod binrnej informcie teploty na BCD
	Digits[0]=TableChar[0];         //
	Digits[1]=TableChar[Temp>>4];   //prprava desiatok teploty
	Digits[2]=TableChar[Temp&0x0F]; //prprava jednotiek teploty
	ElZero();       //Elimincia nepodstatnch nl
	if (Digits[0]==TableChar[0])    //nezobrazenie nepodstatnch nl
			{
			Digits[0]=0xFF;
			if (Digits[1]==TableChar[0]) Digits[1]=0xFF;
			}
}

//Zobrazenie mintiek
void TimerDisplay(unsigned char Num)
{
	unsigned char Temp;     //doasn premmen
	Temp=bin2bcd(Num);  //prevod binrnej informcie teploty na BCD
	Digits[1]=TableChar[Temp>>4];   //prprava desiatok teploty
	Digits[2]=TableChar[Temp&0x0F]; //prprava jednotiek teploty
	//ElZero();       //Elimincia nepodstatnch nl
	if (Digits[1]==TableChar[0]) Digits[1]=0xFF;  //nezobrazenie znaku ke je nula 
	if (F_Timer) 
			{
			Digits[0]=TableTimer[RunTimer];
			}
	else Digits[0]=Char_o;         //
}


//Oberstvenie displeja - tart
void RefreshDisplay (void)
{
	unsigned char Temp;
	if (++PointDig==3) PointDig=0;  //rotcia digitu displeja
	Temp=Digits[PointDig];          //vber zobrazovanho digitu

	O_SegA=CheckBit(Temp,0);        //nastavenie segmentu A pre digit
	O_SegB=CheckBit(Temp,1);        //nastavenie segmentu B pre digit
	O_SegC=CheckBit(Temp,2);        //nastavenie segmentu C pre digit
	O_SegD=CheckBit(Temp,3);        //nastavenie segmentu D pre digit
	O_SegE=CheckBit(Temp,4);        //nastavenie segmentu E pre digit
	O_SegF=CheckBit(Temp,5);        //nastavenie segmentu F pre digit
	O_SegG=CheckBit(Temp,6);        //nastavenie segmentu G pre digit
	O_SegH=CheckBit(Temp,7);        //nastavenie segmentu H pre digit
	switch (PointDig)
			{               
			case 0: O_Dig1=0; break;       //zapnutie 1 digitu
			case 1: O_Dig2=0; break;       //zapnutie 2 digitu
			case 2: O_Dig3=0; break;       //zapnutie 3 digitu
			}
}

// Pin change 0-7 interrupt service routine
interrupt [PC_INT] void pin_change_isr0(void)
{
	GIMSK&=0xDF;    //vypnutie preruenia od zmeny na pine PINB.0 - I_Tl;
	F_IdleS=0;
	CountIdle=0;
}

// Timer 0 output compare A interrupt service routine - each 5ms - 200Hz (64us)
interrupt [TIM0_COMPA] void timer0_compa_isr(void)
{
	char temp;
	unsigned char x;
	
	TCNT0=0;        //pre sprvne nastavenie jasu displeja po prechode z Idle mdu
	if (I_Bat) OCR0B=30;
	else OCR0B=60;       //doba oberstvenia displeja (2 ms) - min. 30, max. 60
	SetBit(TIFR,2);         //reset flagu OCF0B - compare

	if(F_ErrorS) ModeRAM=1;         //prechod na mintky ak je chyba senzoru
	if (ModeRAM==0)
			{ 
			if (F_Flash) SetTemperatureDisplay();         //pre zobrazenie nastavenej teploty
			else TemperatureDisplay ();         //pre zobrazenie teploty         
			}
	if (ModeRAM==1) 
			{
			if (F_Flash) TimerDisplay(ChangeNum);         //pre zobrazenie nastavenej hodnoty mintiek
			else 
					{
					if (F_Timer) TimerDisplay(Timer); 
					else TimerDisplay(SetTimer);         //pre zobrazenie mintiek
					}
			}
	if (ModeRAM==2)
			{
			if (F_Auto)     //automatika je aktvna
					{
					if (!F_TempFinish) TemperatureDisplay ();         //pre zobrazenie teploty
					if (F_Timer) TimerDisplay(Timer);
					}
			else
					{
					Digits[0]=0x88;         //znak A na displej
					Digits[1]=0xE3;         //znak u na displej
					Digits[2]=0x87;         //znak t na displej                
					} 
			}
	if (O_Heat)
			{ 
			if (!F_Auto) ClearBit (Digits[2],7);      //indikcia ohrevu
			else if (F_HalfS) ClearBit (Digits[2],7);
			}
	else SetBit (Digits[2],7);
	if (F_Flash)
			{ 
			if (F_HalfS) 
					{
					if (!F_NoFlash) Digits[0]=0xFF, Digits[1]=0xFF, Digits[2]=0xFF;    //blikanie displeja
					}
			}
	RefreshDisplay();       //obersvenie displeja
	if  (!I_Tl)
			{
			CountTl++;
			if (CountTl==10)    //platnos tlatka 50ms
					{
					F_Tl=1;
					F_Alarm=0;
					CountFiveSek=0;
					F_FiveSek=0;      
					}
			if (CountTl==255) F_LongTl=1;     //platnos tl. - dlhie asy (1,275 sek)
			CountIdle=0;
			}
	else F_Tl=0, CountTl=0;
	
	switch(Conv_DS18B20)
	{
		case 0: break;
		case 1:
		{
			F_ErrorS=1;
			if(w1_init())	// trv asi 498us
			{
				//w1_write(DS18B20_CMD_SKIPROM);	// netaj ROM
				//w1_write(DS18B20_CMD_CONVERTTEMP);	// tart konverzie
				F_ErrorS=0;
				Conv_DS18B20=2;
			}
		}	break;
		case 2:
		{
			w1_write(DS18B20_CMD_SKIPROM);	// netaj ROM
			//w1_write(DS18B20_CMD_CONVERTTEMP);	// tart konverzie
			Conv_DS18B20=3;
		}	break;
		case 3:
		{
			w1_write(DS18B20_CMD_CONVERTTEMP);	// tart konverzie
			Conv_DS18B20=4;
		}	break;
		case 4:
		{
			if(w1_init())	// trv asi 498us
			{
				//w1_write(DS18B20_CMD_SKIPROM);	// netaj ROM
				//w1_write(DS18B20_CMD_RSCRATCHPAD);	// tart konverzie
				F_ErrorS=0;
				Conv_DS18B20=5;
			}
			else Conv_DS18B20=1;
		}	break;
		case 5:
		{
			w1_write(DS18B20_CMD_SKIPROM);	// netaj ROM
			//w1_write(DS18B20_CMD_RSCRATCHPAD);	// tart konverzie
			Conv_DS18B20=6;
		}	break;
		case 6:
		{
			w1_write(DS18B20_CMD_RSCRATCHPAD);	// tart konverzie
			Conv_DS18B20=7;
		}	break;
		case 7:
		{
			// pretanie 2 bytov teploty
			temperature_l=w1_read();
			Conv_DS18B20=8;
			
		}	break;
		case 8:
		{
			// pretanie 2 bytov teploty
			temperature_h=w1_read();
			Conv_DS18B20=9;
		}	break;
		case 9:
		{
			temp=0x0F&temperature_l;	// pre sprvne zobraznie teploty v mnusovch hodnotch
			if(temp==0) x=1;
			temp=( temperature_h << 4 ) | (temperature_l >> 4);		// teplota iba z 8 bitov DS18B20
			if(temp<0)
			{
				F_NegTemp=1;
				temp=~temp;
				temp+=x;
			}
			else F_NegTemp=0;
			Teplota=temp;
			Conv_DS18B20=1;
		}	break;
	}
	
	while (!CheckBit(TIFR,2));     //akaj na dokonenie doby (2 ms)
	O_Dig1=1, O_Dig2=1, O_Dig3=1;   //zhasnutie displeja
}


//Pre kontrolu signlu I_InS - zo senzoru teploty
//void Check_I_InS(void)
//{
	//while (I_InS)     //akaj na L z SMT160
            //{
            //if (CheckBit(TIFR,5)) break;     //akaj na zhodu s OCR1B - 2,05 ms
            //}      
//}
//
//void Check_I_InS_(void)
//{
	//while (!I_InS)      //akaj na H z SMT160
            //{
	            //if (CheckBit(TIFR,5)) break;
            //}
//}

// Timer 1 output compare A interrupt service routine - 2Hz - 0,5 sek. (250 ns/16 us)
interrupt [TIM1_COMPA] void timer1_compa_isr(void)
{
	#asm ("wdr")            //watchdog reset

	F_HalfS=~F_HalfS;       //vytvorenie pol sekundovch pulzov

	if (Teplota<SetTemp-1) O_Heat=1;
	if (Teplota>=SetTemp) O_Heat=0; 
	if (F_NegTemp) O_Heat=1;        //ak je zporn teplota - ohrev
	if (F_ErrorS) O_Heat=0;
	if (++CountFiveSek==10) F_FiveSek=1;
	if (F_Idle)
			{
			if (++CountIdle==20) F_IdleS=1;        //odtavanie asu do prechodu na Idle md
			}
	if (F_Timer)    //zobrazenie znaku beiacich mintiek
			{
			if (++RunTimer==4) RunTimer=0;
			if (++CountTimMin==120)
					{ 
					CountTimMin=0;
					if (--Timer==0) F_Timer=0, F_Alarm=1;
					}
			}
	else CountTimMin=0;
	if (F_Auto)
			{
			if (F_TempFinish)
					{
					if (!F_Timer) F_Auto=0, F_TempFinish=0, F_Alarm=1; //ukonenie automatiky
					}
			else
					{
					if (!O_Heat) F_TempFinish=1, F_Timer=1, F_Alarm=1;
					}
			}
	if (F_Alarm) O_Horn=F_HalfS;  //zvukov signalizcia0
	else O_Horn=1;

	if (F_Signal)
			{
			if(!F_Aux_M) O_Horn=0, F_Aux_M=1;     //zvukov signalizcia - 0,5 sek
			}                       
	else F_Aux_M=0;
}

//Automatick md (pre zavrane) - najskr mus dosiahnu teplotu a po potvrden odtanie asu
void Mode2(void)
{
	F_Flash=0;
	if (!F_Auto)
        {
        if (F_LongTl) F_Auto=1, Timer=SetTimer;    //pri dlhom stlaen - tart automatiky   
        else ModeRAM=0;
        }
	else
        {
        if (F_LongTl) F_Auto=0, F_TempFinish=0, F_Timer=0;    //pri dlhom staen -  koniec automatiky
        }
}

//Zmena mdu a nastavenie parametrov
unsigned char Changes (void)
{
	while (F_Tl);   //wait realese Tl
	if (!F_LongTl) 
			{
			if (ModeRAM==0) ModeRAM=1;      //tlatko stlaen krtko < 2 sekundy - Prechod na Mintky Mod 1
			else ModeRAM=2;
			}
	else
			{
			while (1)
					{
					if (F_Tl)
							{
							ChangeNum++;
							if (ChangeNum>99) ChangeNum=1;
							CountTl=0;
							while (F_Tl)  //wait realese Tl
									{
									F_NoFlash=1;
									if (CountTl==25)        //30 pvodne
											{
											ChangeNum++;
											if (ChangeNum>99) ChangeNum=1;
											CountTl=0; 
											}
									}  
							F_NoFlash=0; 
							}
					if (F_FiveSek) 
							{
							if (ModeRAM==1) F_Timer=1, CountTimMin=0, Timer=ChangeNum;        //tart mintiek
							break;   
							}
					}
			}
	F_Flash=0;        //blikanie displeja ukonen
	//while (F_Tl);  //wait realese Tl
	return ChangeNum; 
}

//Md 1 - mintky
void Mode1 (void)
{
	if (F_Timer)
		{
		if (F_LongTl) F_Timer=0, F_Flash=0;    //pri dlhom stlaen - koniec
		else ModeRAM=0;
		}
	else
		{
		ChangeNum=SetTimer; 
		SetTimer=Changes();
		SetTimerEE=SetTimer;
		}
}

//Md 0 - regulcia teploty
void Mode0(void)
{
	if (!F_ErrorS) 
		{
		ChangeNum=SetTemp; 
		SetTemp=Changes();
		SetTempEE=SetTemp;
		}
	else 
		{
		ModeRAM=1;      //prechod na minutky
		}
}

void main(void)
{
	// Crystal Oscillator division factor: 1
	#pragma optsize-
	CLKPR=0x80;
	CLKPR=0x00;
	#ifdef _OPTIMIZE_SIZE_
	#pragma optsize+
	#endif

	// Input/Output Ports initialization
	// Port A initialization
	// Func2=In Func1=Out Func0=Out 
	// State2=T State1=1 State0=1 
	PORTA=0x03;
	DDRA=0x03;

	// Port B initialization
	// Func7=Out Func6=In Func5=Out Func4=Out Func3=Out Func2=Out Func1=Out Func0=In 
	// State7=1 State6=P State5=1 State4=1 State3=1 State2=1 State1=0 State0=P 
	PORTB=0xFD;
	DDRB=0xBE;

	// Port D initialization
	// Func6=In Func5=Out Func4=Out Func3=Out Func2=Out Func1=Out Func0=Out 
	// State6=P State5=1 State4=1 State3=1 State2=1 State1=1 State0=1 
	PORTD=0x7F;
	DDRD=0x3F;

	// Timer/Counter 0 initialization
	// Clock source: System Clock
	// Clock value: 15,625 kHz
	// Mode: CTC
	// OC0A output: Disconnected
	// OC0B output: Disconnected
	TCCR0A=0x02;
	TCCR0B=0x04;
	//TCNT0=0x00;
	OCR0A=0x4E;
	//OCR0B=0x00;

	// Timer/Counter 1 initialization
	// Clock source: System Clock
	// Clock value: 62,500 kHz
	// Mode: CTC
	// OC1A output: Discon.
	// OC1B output: Discon.
	// Noise Canceler: Off
	// Input Capture on Falling Edge
	// Timer 1 Overflow Interrupt: Off
	// Input Capture Interrupt: Off
	// Compare A Match Interrupt: On
	// Compare B Match Interrupt: Off
	//TCCR1A=0x00;
	TCCR1B=0x0B;
	//TCNT1H=0x00;
	//TCNT1L=0x00;
	//ICR1H=0x00;
	//ICR1L=0x00;
	//OCR1AH=0x7A;
	//OCR1AL=0x12;
	//OCR1BH=0x00;
	//OCR1BL=0x00;
	OCR1A=39321;    //mus by prepotan - men sa deliaci pomer pri meran teploty na /1 (39287)
	OCR1B=8200;       //doba potrebn pre informcie zo senzoru teploty do - 2,05 ms

	// External Interrupt(s) initialization
	// INT0: Off
	// INT1: Off
	// Interrupt on any change on pins PCINT0-7: On
	//GIMSK=0x00;     //preruenie disable - (enable: GIMSK=0x20)
	MCUCR=0x20;     //povolenia sleep modu
	PCMSK=0x01;
	//EIFR=0x20;

	// Timer(s)/Counter(s) Interrupt(s) initialization
	TIMSK=0x41;

	// Universal Serial Interface initialization
	// Mode: Disabled
	// Clock source: Register & Counter=no clk.
	// USI Counter Overflow Interrupt: Off
	//USICR=0x00;

	// Analog Comparator initialization
	// Analog Comparator: Off
	// Analog Comparator Input Capture by Timer/Counter 1: Off
	ACSR=0x80;

	// Watchdog Timer initialization
	// Watchdog Timer Prescaler: OSC/256k
	// Watchdog Timer interrupt: Off
	#pragma optsize-
	WDTCR=0x1F;
	WDTCR=0x0F;
	#ifdef _OPTIMIZE_SIZE_
	#pragma optsize+
	#endif

	/*zpis kalibranho sla pre intern osciltor - od vrobcu sa po resete zapisuje automaticky
	do OSCCAL ale laden pre 3V a 25C - pre V je nutn odta 5.*/
	OSCCAL=OSCCAL-5;        
	/*if (ModeEE==0xFF) ModeEE=0;     //pri prvom zapnut navolenie mdu 0 - regulcia teploty
	ModeRAM=ModeEE;         //prepis zvolenho mdu do RAM pamte*/
	if (SetTempEE==0xFF) SetTempEE=20, SetTimerEE=15;      //vchodzia nastaven teplota 20C + vchodzia hodnota mintiek
	SetTemp=SetTempEE;
	SetTimer=SetTimerEE;

	// Global enable interrupts
	#asm("sei")
	while (!I_Tl)   //tl. zopnut
			{
			if (F_LongTl) F_Idle=1, F_Signal=1;
			}
	while (F_Tl);
	F_Signal=0;

	while (1)
		{
		if(F_Alarm)    //ke je alarm - vyradi tlatko
			{
			while(F_Alarm);
			while(F_Tl);      
			}
		if (F_Tl)
			{
			F_LongTl=0; 
			while (F_Tl)      //wait realese Tl
				{                
				if (F_LongTl)        //tlatko stlaen dlho > 1,5 sekundy + blikanie displeja
						{
						F_Flash=1;
						break;
						}
				}
			switch (ModeRAM)
				{
				case 0: Mode0(); break;        //prechod na md 0 = Regulcia teploty
				case 1: Mode1(); break;       //prechod na md 1 = Mintky
				case 2: Mode2(); break;         //prechod ba md 2 = Automatika pre zavranie
				}
			while (F_Tl);   //wait realese Tl                                                                            
			}
		if (F_IdleS)
			{
			while (F_IdleS)
				{
				EIFR=0x20;      //reset flagu preruenia PIN Change
				TIMSK&=0xFE;    //vypnutie preruenia od Timer0
				GIMSK|=0x20;    //zapnutie preruenia od zmeny na pine PINB.0 - I_Tl;
				#asm ("sleep")  //prechod do Idle mdu
				}
			while (!I_Tl);  //akaj na pustenie tl.       
			TIMSK|=0x01;    //zapnutie preruenia od Timer0
			}
	};
}
